@@ -12,6 +12,9 @@
 #include <ctime>
 #include <limits>
 
+namespace acng
+{
+
 /**
  * @brief Primitive task scheduler for internal helper functions
  *
@@ -25,30 +28,32 @@
  * need to invalidate previous entries sitting in the prio-queue.
  *
  */
-class cleaner : public base_with_condition
+class ACNG_API cleaner : public base_with_condition
 {
 public:
-	cleaner();
 	void Init();
 	virtual ~cleaner();
 
 	void WorkLoop();
 	void Stop();
 
-	enum eType
+	enum eType : char
 	{
-		TYPE_EXFILEITEM, TYPE_ACFGHOOKS, TYPE_EXDNS, TYPE_EXCONNS,
+		TYPE_EXFILEITEM, TYPE_ACFGHOOKS, /* TYPE_EXDNS,*/ TYPE_EXCONNS,
 		ETYPE_MAX
 	};
 	void ScheduleFor(time_t when, eType what);
 	void dump_status();
+	static cleaner& GetInstance(bool initAsNoop=false);
 
 private:
+	cleaner(bool noop=false);
 	pthread_t m_thr;
 	time_t stamps[cleaner::ETYPE_MAX];
 	bool m_terminating = false;
+	bool m_noop=false;
 };
 
-extern cleaner g_victor; // ... down to the nap
+}
 
 #endif /* CLEANER_H_ */
