@@ -17,7 +17,7 @@ typedef std::shared_ptr<fileitem> tFileItemPtr;
 typedef std::unordered_multimap<mstring, tFileItemPtr> tFiGlobMap;
 
 //! Base class containing all required data and methods for communication with the download sources
-class fileitem : public base_with_condition
+class ACNG_API fileitem : public base_with_condition
 {
 public:
 
