@@ -39,7 +39,7 @@ bool CompileExpressions();
 
 namespace cfg {
 
-bool g_bQuiet=false, g_bNoComplex=false;
+bool ACNG_API g_bQuiet=false, g_bNoComplex=false;
 
 extern std::atomic_bool degraded;
 
@@ -74,8 +74,6 @@ struct tProperty
 	std::function<mstring(bool superUser)> get; // returns a string value. A string starting with # tells to skip the output
 };
 
-#ifndef MINIBUILD
-
 // predeclare some
 void _ParseLocalDirs(cmstring &value);
 void AddRemapInfo(bool bAsBackend, const string & token, const string &repname);
@@ -95,7 +93,7 @@ MapNameToString n2sTbl[] = {
 		,{  "CacheDir",                &cachedir}
 		,{  "LogDir",                  &logdir}
 		,{  "SupportDir",              &suppdir}
-		,{  "SocketPath",              &fifopath}
+		,{  "SocketPath",              &udspath}
 		,{  "PidFile",                 &pidfile}
 		,{  "ReportPage",              &reportpage}
 		,{  "VfilePattern",            &vfilepat}
@@ -135,6 +133,7 @@ MapNameToInt n2iTbl[] = {
 		,{  "ExTreshold",                        &extreshhold,      nullptr,    10, true} // wrong spelling :-(
 		,{  "MaxStandbyConThreads",              &tpstandbymax,     nullptr,    10, false}
 		,{  "MaxConThreads",                     &tpthreadmax,      nullptr,    10, false}
+		,{  "DlMaxRetries",                      &dlretriesmax,     nullptr,    10, false}
 		,{  "DnsCacheSeconds",                   &dnscachetime,     nullptr,    10, false}
 		,{  "UnbufferLogs",                      &debug,            nullptr,    10, false}
 		,{  "ExAbortOnProblems",                 &exfailabort,      nullptr,    10, false}
@@ -142,6 +141,8 @@ MapNameToInt n2iTbl[] = {
 		,{  "LogSubmittedOrigin",                &logxff,           nullptr,    10, false}
 		,{  "RecompBz2",                         &recompbz2,        nullptr,    10, false}
 		,{  "NetworkTimeout",                    &nettimeout,       nullptr,    10, false}
+		,{  "FastTimeout",                       &fasttimeout,      nullptr,    10, false}
+		,{  "DisconnectTimeout",                 &discotimeout,     nullptr,    10, false}
 		,{  "MinUpdateInterval",                 &updinterval,      nullptr,    10, false}
 		,{  "ForwardBtsSoap",                    &forwardsoap,      nullptr,    10, false}
 		,{  "KeepExtraVersions",                 &keepnver,         nullptr,    10, false}
@@ -369,7 +370,8 @@ tProperty* GetPropPtr(cmstring& key)
 	return nullptr;
 }
 
-int * GetIntPtr(LPCSTR key) {
+int * GetIntPtr(LPCSTR key)
+{
 	for(auto &ent : n2iTbl)
 		if(0==strcasecmp(key, ent.name))
 			return ent.ptr;
@@ -620,7 +622,7 @@ struct tHookHandler: public tRepoData::IHookHandler, public base_with_mutex
 		{
 			//system(cmdRel.c_str());
 			downTimeNext = ::time(0) + downDuration;
-			g_victor.ScheduleFor(downTimeNext, cleaner::TYPE_ACFGHOOKS);
+			cleaner::GetInstance().ScheduleFor(downTimeNext, cleaner::TYPE_ACFGHOOKS);
 		}
 	}
 	virtual void OnAccess() override
@@ -1137,8 +1139,8 @@ void PostProcConfig()
 	   cfg::requestapx = unEscape(cfg::requestapx);
 
    // create working paths before something else fails somewhere
-   if(!fifopath.empty())
-	   mkbasedir(cfg::fifopath);
+   if(!udspath.empty())
+	   mkbasedir(cfg::udspath);
    if(!cachedir.empty())
 	   mkbasedir(cfg::cachedir);
    if(! pidfile.empty())
@@ -1148,6 +1150,10 @@ void PostProcConfig()
 	   cerr << "Warning: NetworkTimeout value too small, using: 5." << endl;
 	   nettimeout = 5;
    }
+   if(fasttimeout < 0)
+   {
+	   fasttimeout = 0;
+   }
 
    if(RESERVED_DEFVAL == forwardsoap)
 	   forwardsoap = !forcemanaged;
@@ -1366,8 +1372,6 @@ int CheckAdminAuth(LPCSTR auth)
 #endif
 }
 
-#endif // MINIBUILD
-
 static bool proxy_failstate = false;
 acmutex proxy_fail_lock;
 const tHttpUrl* GetProxyInfo()
@@ -1408,7 +1412,7 @@ namespace rex
 	struct { regex_t *pat=nullptr, *extra=nullptr; } rex[ematchtype_max];
 	vector<regex_t> vecReqPatters, vecTgtPatterns;
 
-bool CompileExpressions()
+bool ACNG_API CompileExpressions()
 {
 	auto compat = [](regex_t* &re, LPCSTR ps)
 	{
@@ -1462,7 +1466,7 @@ bool Match(cmstring &in, eMatchType type)
 		|| (type == FILE_VOLATILE && MatchType(in, FILE_SPECIAL_VOLATILE));
 }
 
-eMatchType GetFiletype(const string & in)
+ACNG_API eMatchType GetFiletype(const string & in)
 {
 	if (MatchType(in, FILE_SPECIAL_VOLATILE))
 		return FILE_VOLATILE;
