@@ -7,10 +7,6 @@
 #include <dirwalk.h>
 #include <fcntl.h>
 
-#ifdef HAVE_SSL
-#include <openssl/evp.h>
-#endif
-
 #include <stddef.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -47,7 +43,6 @@
 #include <openssl/sha.h>
 #include <openssl/crypto.h>
 #endif
-
 #include "filereader.h"
 #include "csmapping.h"
 #include "cleaner.h"
@@ -64,23 +59,13 @@ bool isUdsAccessible(cmstring& path)
 	return s && S_ISSOCK(s.st_mode) && 0 == access(path.c_str(), W_OK);
 }
 
-// dummies to satisfy references
-namespace acng
-{
-LPCSTR ReTest(LPCSTR);
-cleaner::cleaner() : m_thr(pthread_t()) {}
-cleaner::~cleaner() {}
-void cleaner::ScheduleFor(time_t, cleaner::eType) {}
-cleaner g_victor;
-}
-
-struct IFitemFactory
+struct ACNG_API IFitemFactory
 {
 	virtual SHARED_PTR<fileitem> Create() =0;
 	virtual ~IFitemFactory() =default;
 };
 
-struct CPrintItemFactory : public IFitemFactory
+struct ACNG_API CPrintItemFactory : public IFitemFactory
 {
 	virtual SHARED_PTR<fileitem> Create()
 	{
@@ -592,8 +577,8 @@ struct TUdsFactory : public ::acng::IDlConFactory
 				}
 				struct sockaddr_un addr;
 				addr.sun_family = PF_UNIX;
-				strcpy(addr.sun_path, cfg::fifopath.c_str());
-				socklen_t adlen = cfg::fifopath.length() + 1 + offsetof(struct sockaddr_un, sun_path);
+				strcpy(addr.sun_path, cfg::udspath.c_str());
+				socklen_t adlen = cfg::udspath.length() + 1 + offsetof(struct sockaddr_un, sun_path);
 				if (connect(m_conFd, (struct sockaddr*) &addr, adlen))
 				{
 					DBGQLOG(tErrnoFmter("connect result: "));
@@ -637,9 +622,9 @@ int maint_job()
 
 	// by default, use the socket connection; if credentials require it -> enforce it
 	bool have_cred = !url.sUserPass.empty(),
-			have_uds = !cfg::fifopath.empty(),
+			have_uds = !cfg::udspath.empty(),
 			try_tcp = !have_cred;
-	bool uds_ok = have_uds && isUdsAccessible(cfg::fifopath);
+	bool uds_ok = have_uds && isUdsAccessible(cfg::udspath);
 
 	if(have_cred)
 	{
@@ -649,7 +634,7 @@ int maint_job()
 		}
 		else if(have_uds && !uds_ok)
 		{
-			cerr << "This operation transmits credentials but the socket (" << cfg::fifopath
+			cerr << "This operation transmits credentials but the socket (" << cfg::udspath
 					<< ") is currently not accessible!" << endl;
 			return EXIT_FAILURE;
 		}
@@ -1060,6 +1045,8 @@ std::unordered_map<string, parm> parms = {
 int main(int argc, const char **argv)
 {
 	using namespace acng;
+	// ensure a harmless object just in case any activity wants to run anything there
+	cleaner::GetInstance(false).notifyAll();
 
 	string exe(argv[0]);
 	unsigned aOffset=1;
